@@ -159,6 +159,7 @@ typedef enum
 typedef enum
 {
   MUTT_WRITE_HEADER_NORMAL,
+  MUTT_WRITE_HEADER_FCC,
   MUTT_WRITE_HEADER_POSTPONE,
   MUTT_WRITE_HEADER_EDITHDRS,
   MUTT_WRITE_HEADER_MIME
@@ -289,7 +290,14 @@ enum
   MUTT_SAVE_OVERWRITE
 };
 
+/* used by init.h MuttVars and Commands dispatch functions */
 /* possible arguments to set_quadoption() */
+union pointer_long_t
+{
+  void *p;
+  long l;
+};
+
 enum
 {
   MUTT_NO,
@@ -324,6 +332,7 @@ enum
   OPT_QUIT,
   OPT_REPLYTO,
   OPT_RECALL,
+  OPT_SENDMULTIPARTALT,
 #if defined(USE_SSL)
   OPT_SSLSTARTTLS,
 #endif
@@ -372,6 +381,10 @@ enum
   OPTASKBCC,
   OPTASKCC,
   OPTATTACHSPLIT,
+#ifdef USE_AUTOCRYPT
+  OPTAUTOCRYPT,
+  OPTAUTOCRYPTREPLY,
+#endif
   OPTAUTOEDIT,
   OPTAUTOSUBSCRIBE,
   OPTAUTOTAG,
@@ -381,11 +394,13 @@ enum
   OPTCHANGEFOLDERNEXT,
   OPTBRAILLEFRIENDLY,
   OPTBROWSERABBRMAILBOXES,
+  OPTBROWSERSTICKYCURSOR,
   OPTCHECKMBOXSIZE,
   OPTCHECKNEW,
   OPTCOLLAPSEUNREAD,
   OPTCONFIRMAPPEND,
   OPTCONFIRMCREATE,
+  OPTCOUNTALTERNATIVES,
   OPTDELETEUNTAG,
   OPTDIGESTCOLLAPSE,
   OPTDUPTHREADS,
@@ -439,6 +454,7 @@ enum
   OPTTLSV1,
   OPTTLSV1_1,
   OPTTLSV1_2,
+  OPTTLSV1_3,
   OPTSSLFORCETLS,
   OPTSSLVERIFYDATES,
   OPTSSLVERIFYHOST,
@@ -503,6 +519,10 @@ enum
 #endif
   OPTSIGDASHES,
   OPTSIGONTOP,
+  OPTSIZESHOWBYTES,
+  OPTSIZESHOWMB,
+  OPTSIZESHOWFRACTIONS,
+  OPTSIZEUNITSONLEFT,
   OPTSORTRE,
   OPTSPAMSEP,
   OPTSTATUSONTOP,
@@ -594,6 +614,7 @@ enum
   OPTPGPCHECKTRUST,	/* (pseudo) used by pgp_select_key () */
   OPTDONTHANDLEPGPKEYS,	/* (pseudo) used to extract PGP keys */
   OPTIGNOREMACROEVENTS, /* (pseudo) don't process macro/push/exec events while set */
+  OPTAUTOCRYPTGPGME,    /* (pseudo) use Autocrypt context inside crypt-gpgme.c */
 
   OPTMAX
 };
@@ -633,6 +654,7 @@ typedef struct replace_list_t
 #define mutt_new_rx_list() safe_calloc (1, sizeof (RX_LIST))
 #define mutt_new_replace_list() safe_calloc (1, sizeof (REPLACE_LIST))
 void mutt_free_list (LIST **);
+void mutt_free_list_generic (LIST **list, void (*data_free)(char **));
 void mutt_free_rx_list (RX_LIST **);
 void mutt_free_replace_list (REPLACE_LIST **);
 LIST *mutt_copy_list (LIST *);
@@ -662,6 +684,17 @@ typedef struct alias
 #define MUTT_ENV_CHANGED_XLABEL  (1<<2)  /* X-Label edited */
 #define MUTT_ENV_CHANGED_SUBJECT (1<<3)  /* Protected header update */
 
+#ifdef USE_AUTOCRYPT
+typedef struct autocrypt
+{
+  char *addr;
+  char *keydata;
+  unsigned int prefer_encrypt : 1;
+  unsigned int invalid : 1;
+  struct autocrypt *next;
+} AUTOCRYPTHDR;
+#endif
+
 typedef struct envelope
 {
   ADDRESS *return_path;
@@ -684,7 +717,10 @@ typedef struct envelope
   LIST *references;		/* message references (in reverse order) */
   LIST *in_reply_to;		/* in-reply-to header content */
   LIST *userhdrs;		/* user defined headers */
-
+#ifdef USE_AUTOCRYPT
+  AUTOCRYPTHDR *autocrypt;
+  AUTOCRYPTHDR *autocrypt_gossip;
+#endif
   unsigned char changed;       /* The MUTT_ENV_CHANGED_* flags specify which
                                 * fields are modified */
 } ENVELOPE;
@@ -786,6 +822,10 @@ typedef struct body
   unsigned int goodsig : 1;	/* good cryptographic signature */
   unsigned int warnsig : 1;     /* maybe good signature */
   unsigned int badsig : 1;	/* bad cryptographic signature (needed to check encrypted s/mime-signatures) */
+#ifdef USE_AUTOCRYPT
+  unsigned int is_autocrypt : 1;  /* used to flag autocrypt-decrypted messages
+                                   * for replying */
+#endif
 
   unsigned int collapsed : 1;	/* used by recvattach */
   unsigned int attach_qualifies : 1;
@@ -797,7 +837,9 @@ typedef struct mutt_thread THREAD;
 
 typedef struct header
 {
-  unsigned int security : 12;  /* bit 0-8: flags, bit 9,10: application.
+  unsigned int security : 14;  /* bit 0-10:   flags
+                                  bit 11-12: application.
+                                  bit 13:    traditional pgp.
                                   see: mutt_crypt.h pgplib.h, smime.h */
 
   unsigned int mime : 1;    		/* has a MIME-Version header? */
